# PackageFromBuiltInFeedResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**package_size_bytes** | **int** |  | [optional] 
**hash** | **str** |  | [optional] 
**nu_get_package_id** | **str** |  | [optional] 
**package_id** | **str** |  | [optional] 
**nu_get_feed_id** | **str** |  | [optional] 
**feed_id** | **str** |  | [optional] 
**title** | **str** |  | [optional] 
**summary** | **str** |  | [optional] 
**version** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**published** | **datetime** |  | [optional] 
**release_notes** | **str** |  | [optional] 
**file_extension** | **str** |  | [optional] 
**package_metadata** | [**OctopusPackageMetadataMappedResource**](OctopusPackageMetadataMappedResource.md) |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


